import { __decorate } from 'tslib';
import { Model, Component, Vue } from 'vue-property-decorator';
import { CoolSelect, CoolSelectPlugin } from 'vue-cool-select';
import { namespace } from 'vuex-class';

const secureToken = namespace('SecureToken');
/**
 * Class-component
 */
let AssociatePicker = class AssociatePicker extends Vue {
    constructor() {
        super(...arguments);
        this.items = [];
        this.selected = null;
        this.loading = false;
        this.timeoutId = null;
        this.noData = false;
    }
    async onSearch(search) {
        const lettersLimit = 2;
        this.noData = false;
        if (search.length < lettersLimit) {
            this.items = [];
            this.loading = false;
            return;
        }
        this.loading = true;
        clearTimeout(this.timeoutId);
        this.timeoutId = setTimeout(async () => {
            const client = await this.sharepointContext.msGraphClientFactory.getClient();
            // https://stackoverflow.com/a/58647582/823927 - We just have to get back a ton of extra fields
            const response = await client
                .api(`/me/people/?$search="${search}"`)
                .version('v1.0')
                .get();
            this.items = response.value.filter((person) => person.userPrincipalName);
            this.loading = false;
            if (!this.items.length) {
                this.noData = true;
            }
        }, 500);
    }
};
__decorate([
    secureToken.Getter
], AssociatePicker.prototype, "sharepointContext", void 0);
__decorate([
    Model('change')
], AssociatePicker.prototype, "value", void 0);
AssociatePicker = __decorate([
    Component({
        components: { CoolSelect },
    })
], AssociatePicker);
var script = AssociatePicker;

function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
    if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
    }
    // Vue.extend constructor export interop.
    const options = typeof script === 'function' ? script.options : script;
    // render functions
    if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true;
        // functional template
        if (isFunctionalTemplate) {
            options.functional = true;
        }
    }
    // scopedId
    if (scopeId) {
        options._scopeId = scopeId;
    }
    let hook;
    if (moduleIdentifier) {
        // server build
        hook = function (context) {
            // 2.3 injection
            context =
                context || // cached call
                    (this.$vnode && this.$vnode.ssrContext) || // stateful
                    (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
            // 2.2 with runInNewContext: true
            if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                context = __VUE_SSR_CONTEXT__;
            }
            // inject component styles
            if (style) {
                style.call(this, createInjectorSSR(context));
            }
            // register component module identifier for async chunk inference
            if (context && context._registeredComponents) {
                context._registeredComponents.add(moduleIdentifier);
            }
        };
        // used by ssr in case component is cached and beforeCreate
        // never gets called
        options._ssrRegister = hook;
    }
    else if (style) {
        hook = shadowMode
            ? function (context) {
                style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
            }
            : function (context) {
                style.call(this, createInjector(context));
            };
    }
    if (hook) {
        if (options.functional) {
            // register for functional component in vue file
            const originalRender = options.render;
            options.render = function renderWithStyleInjection(h, context) {
                hook.call(context);
                return originalRender(h, context);
            };
        }
        else {
            // inject component registration as beforeCreate hook
            const existing = options.beforeCreate;
            options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
    }
    return script;
}

const isOldIE = typeof navigator !== 'undefined' &&
    /msie [6-9]\\b/.test(navigator.userAgent.toLowerCase());
function createInjector(context) {
    return (id, style) => addStyle(id, style);
}
let HEAD;
const styles = {};
function addStyle(id, css) {
    const group = isOldIE ? css.media || 'default' : id;
    const style = styles[group] || (styles[group] = { ids: new Set(), styles: [] });
    if (!style.ids.has(id)) {
        style.ids.add(id);
        let code = css.source;
        if (css.map) {
            // https://developer.chrome.com/devtools/docs/javascript-debugging
            // this makes source maps inside style tags work properly in Chrome
            code += '\n/*# sourceURL=' + css.map.sources[0] + ' */';
            // http://stackoverflow.com/a/26603875
            code +=
                '\n/*# sourceMappingURL=data:application/json;base64,' +
                    btoa(unescape(encodeURIComponent(JSON.stringify(css.map)))) +
                    ' */';
        }
        if (!style.element) {
            style.element = document.createElement('style');
            style.element.type = 'text/css';
            if (css.media)
                style.element.setAttribute('media', css.media);
            if (HEAD === undefined) {
                HEAD = document.head || document.getElementsByTagName('head')[0];
            }
            HEAD.appendChild(style.element);
        }
        if ('styleSheet' in style.element) {
            style.styles.push(code);
            style.element.styleSheet.cssText = style.styles
                .filter(Boolean)
                .join('\n');
        }
        else {
            const index = style.ids.size - 1;
            const textNode = document.createTextNode(code);
            const nodes = style.element.childNodes;
            if (nodes[index])
                style.element.removeChild(nodes[index]);
            if (nodes.length)
                style.element.insertBefore(textNode, nodes[index]);
            else
                style.element.appendChild(textNode);
        }
    }
}

/* script */
const __vue_script__ = script;

/* template */
var __vue_render__ = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("cool-select", {
    ref: "associateSelectManager",
    staticClass: "col-sm-9",
    attrs: {
      value: _vm.value,
      id: "associateSelectManager",
      items: _vm.items,
      loading: _vm.loading,
      "item-text": "displayName",
      placeholder: "Enter associate name",
      "disable-filtering-by-search": "",
      "menu-default-position": "bottom",
      "menu-dynamic-position": "false"
    },
    on: {
      change: function($event) {
        return _vm.$emit("input", $event.target.value)
      },
      search: function($event) {
        return _vm.onSearch($event)
      }
    },
    scopedSlots: _vm._u([
      {
        key: "no-data",
        fn: function() {
          return [
            _vm._v(
              "\n        " +
                _vm._s(
                  _vm.noData
                    ? "No associates found."
                    : "Enter at least 2 letters to search."
                ) +
                "\n    "
            )
          ]
        },
        proxy: true
      },
      {
        key: "item",
        fn: function(ref) {
          var item = ref.item;
          return [
            _c("div", { staticClass: "item" }, [
              _c("img", {
                staticClass: "logo",
                attrs: {
                  src:
                    "https://mccowngordon.sharepoint.com/_layouts/15/userphoto.aspx?size=S&accountname=" +
                    item.userPrincipalName
                }
              }),
              _vm._v(" "),
              _c("div", [
                _c("span", { staticClass: "item-name" }, [
                  _vm._v(_vm._s(item.displayName))
                ]),
                _vm._v(" "),
                _c("br"),
                _vm._v(" "),
                _c("span", { staticClass: "item-domain" }, [
                  _vm._v(_vm._s(item.jobTitle))
                ])
              ])
            ])
          ]
        }
      }
    ])
  })
};
var __vue_staticRenderFns__ = [];
__vue_render__._withStripped = true;

  /* style */
  const __vue_inject_styles__ = function (inject) {
    if (!inject) return
    inject("data-v-068bb8cc_0", { source: "@import 'vue-cool-select/dist/themes/bootstrap.css';\n.item {\n  display: flex;\n  align-items: center;\n}\n.item-name {\n  font-size: 25px;\n}\n.item-domain {\n  color: grey;\n}\n.logo {\n  max-width: 60px;\n  margin-right: 10px;\n  border: 1px solid #eaecf0;\n}\n.loading-indicator {\n  width: 20px;\n  margin-right: 10px;\n}\n\n/*# sourceMappingURL=AssociatePicker.vue.map */", map: {"version":3,"sources":["C:\\Users\\astanley\\local web\\npm packages\\vue-ui-components\\src\\components\\AssociatePicker.vue","AssociatePicker.vue"],"names":[],"mappings":"AAkGA,mDAAA;AACA;EACA,aAAA;EACA,mBAAA;ACjGA;ADoGA;EACA,eAAA;ACjGA;ADmGA;EACA,WAAA;AChGA;ADmGA;EACA,eAAA;EACA,kBAAA;EACA,yBAAA;AChGA;ADmGA;EACA,WAAA;EACA,kBAAA;AChGA;;AAEA,8CAA8C","file":"AssociatePicker.vue","sourcesContent":["<template>\n    <cool-select\n        :value=\"value\"\n        @change=\"$emit('input', $event.target.value)\"\n        id=\"associateSelectManager\"\n        ref=\"associateSelectManager\"\n        :items=\"items\"\n        :loading=\"loading\"\n        item-text=\"displayName\"\n        placeholder=\"Enter associate name\"\n        disable-filtering-by-search\n        menu-default-position=\"bottom\"\n        menu-dynamic-position=\"false\"\n        @search=\"onSearch($event)\"\n        class=\"col-sm-9\"\n    >\n        <template #no-data>\n            {{ noData ? 'No associates found.' : 'Enter at least 2 letters to search.' }}\n        </template>\n        <template #item=\"{ item }\">\n            <div class=\"item\">\n                <img\n                    :src=\"\n                        'https://mccowngordon.sharepoint.com/_layouts/15/userphoto.aspx?size=S&accountname=' +\n                            item.userPrincipalName\n                    \"\n                    class=\"logo\"\n                />\n\n                <div>\n                    <span class=\"item-name\">{{ item.displayName }}</span>\n                    <br />\n                    <span class=\"item-domain\">{{ item.jobTitle }}</span>\n                </div>\n            </div>\n        </template>\n    </cool-select>\n</template>\n\n<script lang=\"ts\">\nimport { Vue, Component, Prop, Model } from 'vue-property-decorator';\n\nimport { CoolSelect } from 'vue-cool-select';\nimport { MSGraphClient } from '@microsoft/sp-http';\n\nimport { namespace } from 'vuex-class';\nconst secureToken = namespace('SecureToken');\n\n/**\n * Class-component\n */\n\n@Component({\n    components: { CoolSelect },\n})\nexport default class AssociatePicker extends Vue {\n    @secureToken.Getter\n    public sharepointContext;\n\n    items = [];\n    selected = null;\n    loading = false;\n    timeoutId: any = null;\n    noData = false;\n\n    @Model('change')\n    public value;\n\n    public async onSearch(search) {\n        const lettersLimit = 2;\n\n        this.noData = false;\n        if (search.length < lettersLimit) {\n            this.items = [];\n            this.loading = false;\n            return;\n        }\n        this.loading = true;\n\n        clearTimeout(this.timeoutId);\n        this.timeoutId = setTimeout(async () => {\n            const client: MSGraphClient = await this.sharepointContext.msGraphClientFactory.getClient();\n            // https://stackoverflow.com/a/58647582/823927 - We just have to get back a ton of extra fields\n            const response = await client\n                .api(`/me/people/?$search=\"${search}\"`)\n                .version('v1.0')\n                .get();\n            this.items = response.value.filter((person) => person.userPrincipalName);\n            this.loading = false;\n            if (!this.items.length) {\n                this.noData = true;\n            }\n        }, 500);\n    }\n}\n</script>\n\n<style lang=\"scss\">\n@import 'vue-cool-select/dist/themes/bootstrap.css';\n.item {\n    display: flex;\n    align-items: center;\n}\n\n.item-name {\n    font-size: 25px;\n}\n.item-domain {\n    color: grey;\n}\n\n.logo {\n    max-width: 60px;\n    margin-right: 10px;\n    border: 1px solid #eaecf0;\n}\n\n.loading-indicator {\n    width: 20px;\n    margin-right: 10px;\n}\n</style>\n","@import 'vue-cool-select/dist/themes/bootstrap.css';\n.item {\n  display: flex;\n  align-items: center;\n}\n\n.item-name {\n  font-size: 25px;\n}\n\n.item-domain {\n  color: grey;\n}\n\n.logo {\n  max-width: 60px;\n  margin-right: 10px;\n  border: 1px solid #eaecf0;\n}\n\n.loading-indicator {\n  width: 20px;\n  margin-right: 10px;\n}\n\n/*# sourceMappingURL=AssociatePicker.vue.map */"]}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__ = undefined;
  /* module identifier */
  const __vue_module_identifier__ = undefined;
  /* functional template */
  const __vue_is_functional_template__ = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__ = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
    __vue_inject_styles__,
    __vue_script__,
    __vue_scope_id__,
    __vue_is_functional_template__,
    __vue_module_identifier__,
    false,
    createInjector,
    undefined,
    undefined
  );

// import Vuex from 'vuex';
// Declare install function executed by Vue.use()
function install(Vue) {
    if (install.installed) {
        return;
    }
    install.installed = true;
    // check to see if vue secure plugin is installed and throw an error if not
    // we need sharepointContext to work
    Vue.use(CoolSelectPlugin);
    Vue.component('AssociatePicker', __vue_component__);
}
// Create module definition for Vue.use()
const plugin = {
    install,
};
// Auto-install when vue is found (eg. in browser via <script> tag)
let GlobalVue;
if (typeof window !== 'undefined') {
    GlobalVue = window.Vue;
}
else if (typeof global !== 'undefined') {
    GlobalVue = global.Vue;
}
if (GlobalVue) {
    GlobalVue.use(plugin);
}
// export { AssociatePicker };

export default plugin;
//# sourceMappingURL=vueUIComponents.esm.js.map
